@@ -2,7 +2,8 @@ from ibmdbpy4nps import IdaDataBase, IdaDataFrame
 
 from ibmdbpy4nps.ae.install import NZInstall
 
+idadb = IdaDataBase('weather', 'admin', 'password')
 
-nzinstall = NZInstall(package_name='scikit-learn')
+nzinstall = NZInstall(idadb, package_name='scikit-learn')
 print(nzinstall.getResultCode())
 
